resolve_path

Function resolve_path 

fn resolve_path(
    config: &DiagnosticsMapConfig,
    workspace_root: &AbsPath,
    file_name: &str,
) -> AbsPathBuf
Resolves paths applying any matching path prefix remappings, and then joining the path to the workspace root.