fn resolve_path(
config: &DiagnosticsMapConfig,
workspace_root: &AbsPath,
file_name: &str,
) -> AbsPathBufExpand description
Resolves paths applying any matching path prefix remappings, and then joining the path to the workspace root.
fn resolve_path(
config: &DiagnosticsMapConfig,
workspace_root: &AbsPath,
file_name: &str,
) -> AbsPathBufResolves paths applying any matching path prefix remappings, and then joining the path to the workspace root.